@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2013 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -16,6 +13,7 @@
 #include <aqhbci/aqhbci.h>
 #include <aqhbci/tanmethod.h>
 #include <gwenhywfar/misc.h>
+#include <gwenhywfar/stringlist.h>
 
 
 /** @defgroup G_AB_BE_AQHBCI_USER HBCI User Extensions
@@ -73,6 +71,10 @@ extern "C" {
  */
 #define AH_USER_FLAGS_TAN_OMIT_SMS_ACCOUNT      0x00000200
 
+#define AH_USER_FLAGS_TLS_ONLY_SAFE_CIPHERS     0x00000400
+
+#define AH_USER_FLAGS_USE_STRICT_SEPA_CHARSET   0x00000800
+
     /*@}*/
 
 
@@ -215,6 +217,16 @@ AQHBCI_API
 int AH_User_GetHbciVersion(const AB_USER *u);
 AQHBCI_API
 void AH_User_SetHbciVersion(AB_USER *u, int i);
+
+
+AQHBCI_API
+const char *AH_User_GetSepaTransferProfile(const AB_USER *u);
+AQHBCI_API
+void AH_User_SetSepaTransferProfile(AB_USER *u, const char *profileName);
+AQHBCI_API
+const char *AH_User_GetSepaDebitNoteProfile(const AB_USER *u);
+AQHBCI_API
+void AH_User_SetSepaDebitNoteProfile(AB_USER *u, const char *profileName);
 /*@}*/
 
 
@@ -290,7 +302,7 @@ AQHBCI_API void AH_User_SetMaxDebitNotesPerJob(AB_USER *u, int i);
 
 
 
-
+AQHBCI_API const char *AH_User_FindSepaDescriptor(AB_USER *u, const char *tmpl);
 
 
 /*@}*/ /* defgroup */
