@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2011 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -61,6 +58,13 @@ void AH_User_SetBpd(AB_USER *u, AH_BPD *bpd);
 GWEN_DB_NODE *AH_User_GetUpd(const AB_USER *u);
 void AH_User_SetUpd(AB_USER *u, GWEN_DB_NODE *n);
 
+GWEN_DB_NODE *AH_User_GetUpdForAccount(const AB_USER *u, const AB_ACCOUNT *acc);
+
+GWEN_DB_NODE *AH_User_GetUpdForAccountIdAndSuffix(const AB_USER *u,
+                                                  const char *sAccountNumber,
+                                                  const char *sAccountSuffix);
+
+
 
 int AH_User_GetUpdVersion(const AB_USER *u);
 void AH_User_SetUpdVersion(AB_USER *u, int i);
@@ -87,6 +91,14 @@ int AH_User_InputTanWithChallenge(AB_USER *u,
 				  int minLen,
                                   int maxLen);
 
+/* for optical challenges */
+int AH_User_InputTanWithChallenge2(AB_USER *u,
+                                   const char *challenge,
+                                   const char *challengeHhd,
+                                   char *pwbuffer,
+                                   int minLen,
+                                   int maxLen);
+
 int AH_User_SetTanStatus(AB_USER *u,
 			 const char *challenge,
 			 const char *tan,
@@ -97,6 +109,9 @@ int AH_User_SetPinStatus(AB_USER *u,
 			 GWEN_GUI_PASSWORD_STATUS status);
 
 
+const GWEN_STRINGLIST *AH_User_GetSepaDescriptors(AB_USER *u);
+
+
 
 #endif /* AH_USER_L_H */
 
